
CRUD App with Command Line
==========================

This is a fully functional CRUD command-line app:

.. literalinclude :: cli.py
    :language: python

Read more about argparse: `argparse docs <https://docs.python.org/3/library/argparse.html>`_